import Joi, { ObjectSchema } from 'joi';
import { Algorithm } from 'jsonwebtoken';
export * from 'jsonwebtoken';
export declare enum TokenKind {
    TOKEN = "Token",
    REFRESH_TOKEN = "RefreshToken"
}
export declare enum Channel {
    MERCHANT = "MERCHANT",
    CONSUMER = "CONSUMER",
    ADMIN = "ADMIN"
}
export declare type BaseToken = {
    kind: TokenKind;
    channel: Channel;
    iat?: number;
    exp?: number;
};
export declare const schemaBaseToken: {
    kind: Joi.StringSchema;
    channel: Joi.StringSchema;
    iat: Joi.NumberSchema;
    exp: Joi.NumberSchema;
};
export declare abstract class JwtBaseToken<T> {
    protected readonly secret: string;
    protected readonly algorithm: Algorithm;
    protected readonly schema: ObjectSchema<T>;
    constructor(secret: string, algorithm: Algorithm, schema: ObjectSchema<T>);
    sign(payload: T, expiresIn: string | number, notBefore?: string | number): string;
    verify(token: string): T;
}
